@@ -74,7 +74,9 @@ async def process_folder(source, destination, pack=True):
 @click.argument("destination", default="unpacked")
 def unpack_files(source, destination):
     click.echo(f"Unpacking from {source} to {destination}!")
-    asyncio.run(process_folder(source, destination, False))
+    loop = asyncio.get_event_loop()
+    loop.run_until_complete(process_folder(source, destination, False))
+    # asyncio.run(process_folder(source, destination, False))
 
 
 @click.command()
@@ -82,7 +84,9 @@ def unpack_files(source, destination):
 @click.argument("destination", default="packed")
 def pack_files(source, destination):
     click.echo(f"Packing from {source} to {destination}!")
-    asyncio.run(process_folder(source, destination, True))
+    loop = asyncio.get_event_loop()
+    loop.run_until_complete(process_folder(source, destination, True))
+    # asyncio.run(process_folder(source, destination, True))
 
 
 if __name__ == "__main__":
